package com.yunzhi.nanyang.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yunzhi.nanyang.common.BaseController;
import com.yunzhi.nanyang.common.Constants;
import com.yunzhi.nanyang.common.ResponseBean;
import com.yunzhi.nanyang.entity.TaPerson;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import com.yunzhi.nanyang.service.ITaOrderService;
import com.yunzhi.nanyang.entity.TaOrder;
import org.springframework.web.bind.annotation.RestController;

/**
 * <p>
    * 订单表 前端控制器
    * </p>
 *
 * @author yansen
 * @since 2022-03-08
 */

@Api(tags = "订单表")
@RestController
@RequestMapping("/")
public class TaOrderController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TaOrderController.class);

    @Autowired
    public ITaOrderService iTaOrderService;


    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/{client}/{clientId}/order",method= RequestMethod.GET)
    @ApiOperation(value="列表", notes = "列表", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean taOrderList(@ApiParam("页码") @RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
									 @ApiParam("单页数据量") @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize,
                                    @ApiParam("我的") @RequestParam(value = "mine", defaultValue = "false") Boolean isMine) throws Exception{
        TaPerson taPerson = currentPerson();

        IPage<TaOrder> pg = new Page<>(pageNum, pageSize);
        QueryWrapper<TaOrder> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq(isMine, "person_id", taPerson.getPersonId());
        queryWrapper.eq("status", Constants.STATUS_NORMAL);
        queryWrapper.orderByDesc("create_date");

        IPage<TaOrder> result = iTaOrderService.page(pg, queryWrapper);
        return ResponseBean.success(result);
    }

    /**
     * 保存对象
     * @param taOrder 实体对象
     * @return
     */
    @RequestMapping(value="/{client}/{clientId}/order",method= RequestMethod.POST)
    @ApiOperation(value="生成订单", notes = "生成订单", httpMethod = "POST", response = ResponseBean.class)
    public ResponseBean taOrderAdd(@ApiParam("客户端") @PathVariable String client,
                                   @ApiParam("客户端ID") @PathVariable String clientId,
                                   @ApiParam("保存内容") @RequestBody TaOrder taOrder) throws Exception{
        TaPerson taPerson = currentPerson();

        String orderNo = iTaOrderService.getNextOrderNO();

        taOrder.setOrderId(null);
        taOrder.setOrderNo(orderNo);
        taOrder.setPersonId(taPerson.getPersonId());

        if (iTaOrderService.save(taOrder)){
            return ResponseBean.success(taOrder);
        }else {
            return ResponseBean.error("保存失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     */
    @RequestMapping(value="/{client}/{clientId}/order/{id}", method= RequestMethod.DELETE)
    @ApiOperation(value="取消订单", notes = "取消订单", httpMethod = "DELETE", response = ResponseBean.class)
    public ResponseBean taOrderDelete(@ApiParam("对象ID") @PathVariable String id) throws Exception{

        TaPerson taPerson = currentPerson();
        //
        TaOrder taOrder = iTaOrderService.getById(id);
        if (null == taOrder || taOrder.getStatus() == Constants.STATUS_DELETE) {
            return ResponseBean.error("未找到订单信息");
        }

        if (!taOrder.getPersonId().equals(taPerson.getPersonId())) {
            return ResponseBean.error("无权操作");
        }

        if (taOrder.getPayStatus() == Constants.PAY_PAID) {
            return ResponseBean.error("订单已支付");
        }

        if(iTaOrderService.removeLogicById(id)){
            return ResponseBean.success("success");
        }else {
            return ResponseBean.error("删除失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/{client}/{clientId}/order/{id}",method= RequestMethod.GET)
    @ApiOperation(value="详情", notes = "详情", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean taOrderGet(@ApiParam("对象ID") @PathVariable String id) throws Exception{
        return ResponseBean.success(iTaOrderService.getById(id));
    }
}
